# pyinspirationquotes

🎯 This is simple and fun Python package that provides random inspirational quotes from a collection of 180+ motivational quotes.

# 📦 Installation

You can install the package directly using `pip`:

## 🚀 Usage

from pyinspirationquotes import get_quote

print(get_quote())

Each time you call `get_quote()`, it returns a random motivational quote from a preloaded list.

or 

Jot pyinspirationquotes directly in the terminal to get inspirational quote in your terminal directly🔥


## 📁 Example Output

Push yourself because no one else is going to do it for you.

## 📚 How It Works

The package reads quotes from an internal `quotes.txt` file and selects one at random.

## 🔧 Development

To install and run locally for development:

git clone https://github.com/akankshasoni024/pyinspirationquotes.git
cd pyinspirationquotes
pip install -e .


To test locally:

python
>>> from pyinspirationquotes import get_quote
>>> get_quote()


## 📄 Verification

This project is Verified By Pypi.

## 📩 Connect with me 

Made with ❤️ by [Akanksha Soni]

Github : https://github.com/akankshasoni024
Gmail: aakankshasoni024@gmail.com
Linkedin: https://www.linkedin.com/in/akankshasoni024/

Happy to Connect!
